# AI Context Files

**NOTE: THE FILES IN THIS DIRECTORY ARE GENERATED. DO NOT EDIT THEM DIRECTLY.**

These files are generated by running the `build_git_collector_files.py` script. They provide convenient context for sharing with LLMs.

These differ from the files in the `ai_context/generated` directory in that they are collected from GitHub repos via the [git-collector](https://www.npmjs.com/package/git-collector) tool and then refreshed via `git-collector --update ai_context/git_collector`. This allows for the files to be periodically updated with the latest content from the respective repositories.

To generate these files, run the script from the repository root:

```bash
# Navigate to the repository root
cd /path/to/your/repo

# Run the script to generate AI context files
make ai-context-files
```

Rebuild these files whenever you want the latest content from the respective repositories.

To create new files, you can use the [git-collector](https://www.npmjs.com/package/git-collector) tool. See it's readme for more details on how to use it.
